@@ -1,6 +1,6 @@
 import json, base64, os, pickle, datetime, string, re
 
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 ### from ipynb extract markdown and noted output for document organization
 
 class nbparser:
@@ -304,7 +304,7 @@ git commit -m "Auto commit from nbresnote `date +%F`"
 
 pushsource = """#!/bin/bash
 cd wiki
-git fetch && git push
+git fetch && git pull && git push
 """
 
 
